@@ -24,3 +24,8 @@ if (!defined('WP_UNINSTALL_PLUGIN')) {
 
 // Delete options that this plugin has set.
 delete_option('civicrm_activation_in_progress');
+delete_option('civicrm_rules_flushed');
+
+// TODO: Remove the CiviCRM Base Page(s).
+// TODO: Remove the directory/directories that "civicrm.settings.php" lives in.
+// TODO: Remove the CiviCRM database(s).
