@@ -212,19 +212,23 @@ if (!defined('CIVICRM_WPCLI_LOADED')) {
 
       civicrm_initialize();
 
-      // CRM-18062: Set CiviCRM timezone if any.
-      $wp_base_timezone = date_default_timezone_get();
-      $wp_user_timezone = $this->getOption('timezone', get_option('timezone_string'));
-      if ($wp_user_timezone) {
-        date_default_timezone_set($wp_user_timezone);
+      /*
+       * CRM-12523
+       * WordPress has it's own timezone calculations. CiviCRM relies on the PHP
+       * default timezone which WordPress overrides with UTC in wp-settings.php
+       */
+      $original_timezone = date_default_timezone_get();
+      $wp_site_timezone = $this->getOption('timezone', $this->getTimeZoneString());
+      if ($wp_site_timezone) {
+        date_default_timezone_set($wp_site_timezone);
         CRM_Core_Config::singleton()->userSystem->setMySQLTimeZone();
       }
 
       $result = civicrm_api($entity, $action, $params);
 
-      // Restore WordPress's timezone.
-      if ($wp_base_timezone) {
-        date_default_timezone_set($wp_base_timezone);
+      // Restore original timezone.
+      if ($original_timezone) {
+        date_default_timezone_set($original_timezone);
       }
 
       switch ($this->getOption('out', 'pretty')) {
@@ -246,6 +250,53 @@ if (!defined('CIVICRM_WPCLI_LOADED')) {
 
     }
 
+    /**
+     * Returns the timezone string for the current WordPress site.
+     *
+     * If a timezone identifier is used, return that.
+     * If an offset is used, try to build a suitable timezone.
+     * If all else fails, uses UTC.
+     *
+     * @since 5.64
+     *
+     * @return string $tzstring The site timezone string.
+     */
+    private function getTimeZoneString() {
+
+      // Return the timezone string when set.
+      $tzstring = get_option('timezone_string');
+      if (!empty($tzstring)) {
+        return $tzstring;
+      }
+
+      /*
+       * Try and build a deprecated (but currently valid) timezone string
+       * from the GMT offset value.
+       *
+       * Note: manual offsets should be discouraged. WordPress works more
+       * reliably when setting an actual timezone (e.g. "Europe/London")
+       * because of support for Daylight Saving changes.
+       *
+       * Note: the IANA timezone database that provides PHP's timezone
+       * support uses (reversed) POSIX style signs.
+       *
+       * @see https://www.php.net/manual/en/timezones.others.php
+       */
+      $offset = get_option('gmt_offset');
+      if (0 != $offset && floor($offset) == $offset) {
+        $offset_string = $offset > 0 ? "-$offset" : '+' . abs((int) $offset);
+        $tzstring = 'Etc/GMT' . $offset_string;
+      }
+
+      // Default to "UTC" if the timezone string is still empty.
+      if (empty($tzstring)) {
+        $tzstring = 'UTC';
+      }
+
+      return $tzstring;
+
+    }
+
     /**
      * Implementation of command 'cache-clear'.
      *
